==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/appconfiguration/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appconfiguration.kotlin.inputs

import com.pulumi.azurenative.appconfiguration.inputs.SkuArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a configuration store SKU.
 * @property name The SKU name of the configuration store.
 */
public data class SkuArgs(
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.appconfiguration.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.appconfiguration.inputs.SkuArgs =
        com.pulumi.azurenative.appconfiguration.inputs.SkuArgs.builder()
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value The SKU name of the configuration store.
     */
    @JvmName("flayblpswwbbpmrx")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The SKU name of the configuration store.
     */
    @JvmName("dtbrphowoomsuvbc")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appconfiguration/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appconfiguration.kotlin.inputs

import com.pulumi.azurenative.appconfiguration.inputs.SkuArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a configuration store SKU.
 * @property name The SKU name of the configuration store.
 */
public data class SkuArgs(
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.appconfiguration.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.appconfiguration.inputs.SkuArgs =
        com.pulumi.azurenative.appconfiguration.inputs.SkuArgs.builder()
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value The SKU name of the configuration store.
     */
    @JvmName("ojdwvesgahcwqshm")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The SKU name of the configuration store.
     */
    @JvmName("evsgfgxpyvxxqwlp")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
